#
# spec file for package fuzzel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fuzzel
Version:        1.9.2
Release:        1.1
Summary:        A Wayland-native application launcher, similar to rofi's drun mode
License:        MIT
Group:          System/X11/Utilities
URL:            https://codeberg.org/dnkl/fuzzel
Source:         https://codeberg.org/dnkl/fuzzel/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  meson >= 0.58
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  scdoc
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fcft) <  4.0.0
BuildRequires:  pkgconfig(fcft) >= 3.0.0
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tllist) >= 1.0.1
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(xkbcommon)
%if 0%{?sle_version} >= 150400
BuildRequires:  gcc11
%else
BuildRequires:  gcc >= 8
%endif

%description
A Wayland-native application launcher, similar to rofi's drun mode.

%prep
%autosetup -n %name -p1

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh

%description    zsh-completion
Zsh command-line completion support for %{name}

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%build
export CFLAGS="%{optflags}"
%meson \
-Denable-cairo=enabled -Dpng-backend=libpng -Dsvg-backend=nanosvg \
%if 0%{?sle_version} == 150400 && 0%{?is_opensuse}
# For whatever reason, meson >= 0.58 should already support the c18 standard.
	-Dc_std=c11 \
%endif
    -Db_lto=true

%meson_build

%install
%meson_install

%files
%dir %{_datadir}/doc/%{name}
%license %{_datadir}/doc/%{name}/LICENSE
%doc %{_datadir}/doc/%{name}/README.md
%{_datadir}/doc/%{name}/CHANGELOG.md

%{_bindir}/%{name}

%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man5/%{name}.ini.5%{?ext_man}

%dir %{_sysconfdir}/xdg/%{name}
%config(noreplace) %{_sysconfdir}/xdg/%{name}/%{name}.ini

%files zsh-completion
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/fuzzel.fish

%changelog
* Fri Jul 14 2023 llyyr <llyyr.public@gmail.com>
- Update to 1.9.2:
  * Added a new option --filter-desktop
  * Added missing zsh+fish completions for --password
  * Output scaling is now applied to the border radius
  * Last line sometimes not being rendered
  * key-bindings.cursor-right-word not being recognized as a valid action
  * password-character being set in fuzzel.ini incorrectly enabling password mode
* Tue Apr 11 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix specfile
* Sat Apr  8 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove 0000-wayland-regression-dont-reference-app-when-null.patch
- Update to version 1.9.1
  - Fixed:
  * Regression: default font size was unintentionally changed from 12pt in 1.8.2, to 8pt in 1.9.0. The old default of 12pt has now been restored.
  * Regression: crash when pressing Enter and the match list is empty (e.g. when trying to execute a command line)
- Improvement of specfile
* Thu Mar 30 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0000-wayland-regression-dont-reference-app-when-null.patch
* Tue Mar 28 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.9.0:
  - Added:
  * Add support for startup notifications via xdg activation.
  * Convert tabs to spaces when rendering.
  * --dmenu0 command line option. Like --dmenu, but input is NUL separated instead of newline separated.
  * Support for localized strings. If you want the old behavior, run fuzzel with LC_MESSAGES=C.
  * Export FUZZEL_DESKTOP_FILE_ID environment variable when setting the --launch-prefix in order to pass the Desktop File ID to the launch prefix.
  * New key bindings: [key-bindings].first and [key-bindings].last, bound to Control+Home and Control+End by default.
  * New key binding: [key-bindings].insert-selected, bound to Control+Tab by default. It replaces the current prompt with the selected item.
  - Changed:
  * Better verification of color values specified on the command line.
  * When determining initial font size, do FontConfig config substitution if the user-provided font pattern has no {pixel}size option.
  - Fixed:
  * Update nanosvg to f0a3e10. Fixes rendering of certain SVG icons.
  * Not being able to input numbers using the keypad.
  * Absolute path PNG icons not being loaded.
* Sat Nov  5 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.2:
  - Added:
  * Fish completions
  - Fixed:
  * Unsupported icon formats not being skipped when loading application icons.
  * Wrong size of PNG icons selected (#182)
* Fri Oct 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.1:
  - Fixed:
  * Regression: not able to input text with modifiers (e.g. Shift) pressed (#177).
* Tue Oct 25 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.0:
  - Added:
  * Support for file based configuration.
  * Customizable key bindings.
  * "Custom" key bindings (like Rofi’s `kb-custom-N` key
    bindings).
  * If `argv[0]` is _dmenu_, fuzzel now starts in dmenu mode.
  * `--password=[CHARACTER]` command line option. Intended to be used
    with “password input”; all typed text is rendered as _CHARACTER_,
    defaulting to `*` if _CHARACTER_ is omitted.
  * `Ctrl+y` binding to execute selected entry.
  * `Ctrl+j`/`Ctrl+k` binding to move to the next/previous item.
  * Escape sequences in `Exec` arguments are now supported.
  * Quoted environment variables in `Exec` arguments are now supported.
  * Multiple space-separated search words can now be entered at the prompt.
  * `-M,--selection-match-color`, that lets you configure the color of
    matched substrings of the currently selected item
  * New config option `image-size-ratio`, allowing you to control the
    size of the large image displayed when there are only a “few”
    matches.
  * Support for icons in dmenu mode, using Rofi’s extended dmenu
    protocol.
  * `--layer` command line option, allowing you to choose which layer to
    render the fuzzel window on (`top` or `overlay`).
  * `--no-exit-on-keyboard-focus-loss` command line option
    (`exit-on-keyboard-focus-loss` config option).
  - Changed:
  * `-i` is now **ignored**. This is to increase compatibility with
    other similar utilities. To set the icon theme, either use the long
    option (`--icon-theme=THEME`), or set it in the configuration file
    (default: `$XDG_CONFIG_HOME/fuzzel/fuzzel.ini`).
  * Minimum required meson version is now 0.58.
  * libpng warnings are now routed through fuzzel’s logging
    ([#101][101]).
  * Nanosvg is now the default SVG backend. librsvg is still supported,
    and can be used by setting the `-Dsvg-backend=librsvg` meson option.
  * It is no longer necessary to close stdin when using fuzzel in dmenu
    mode, as long as `--no-run-if-empty` is **not** being used.
  * Improved performance of initial rendering of icons.
  * `--terminal` now defaults to `$TERMINAL -e`.
  * Font shaping is now applied to the prompt
  * The large image displayed when there are only a “few” matches is now
    smaller by default.
  * Swapped meaning of the command line options `-p` and `-P`; `-p` is
    now the short option for `--prompt`.
  * Do not add icon-sized padding on the left size in dmenu mode.
  * Color config values are now allowed to be prefixed with `#`.
  - Fixed:
  * User `.desktop` entries with `NoDisplay=true` not overriding system
    entries.
  * Icon lookup is now better at following the XDG specification.
  * Backspace removes not only the previous character, but also
    everything **after** the cursor.
  * Crash on exit in dmenu mode when selection list is empty.
  * Keypad `enter` not executing the selected entry
- Fix build for meson having issue with c18 standard in spec by
  setting it to none. C18 standard is already supported in
  meson long before version 0.58.
* Fri Apr 22 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- remove librsvg-2.0 as build dependency:
  * we use nanosvg that is bundled with the package instead with flag '-Dsvg-backend=nanosvg'
* Mon Mar  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec file for fuzzel (1.7.0)
